Attribute Macro bitbar_derive::command [−][src]
#[command]Expand description
Registers a subcommand that you can run from a menu item’s command.
Commands should have the signature fn(impl Iterator<Item = OsString>) -> Result<(), Error>, where Error is any type that implements Display. If a command errors, bitbar will attempt to send a macOS notification containing the error message.
Using this requires a main function annotated with bitbar::main.